# -*- coding: utf-8 -*-
"""
OS-specific functionality. Skype access currently only under Windows.

@author      Erki Suurjaak
@created     08.11.2011
@modified    25.02.2013
"""
import csv
import ctypes
import os
import re
import Skype4Py
import Skype4Py.enums

import conf

"""Skype4Py.Skype instance, if any."""
skype_handle = None


def shutdown_skype():
    """Posts a message to the running Skype application to close itself."""
    global skype_handle
    if not skype_handle:
        skype_handle = Skype4Py.Skype()
    skype_handle.Client.Shutdown()


def is_skype_running():
    """Returns whether Skype is currently running."""
    global skype_handle
    if not skype_handle:
        skype_handle = Skype4Py.Skype()
    return skype_handle.Client.IsRunning


def launch_skype():
    """Tries to launch Skype, returns True on success."""
    global skype_handle
    if not skype_handle:
        skype_handle = Skype4Py.Skype()
    skype_handle.Client.Start()


def search_skype_contact(value):
    """
    Searches for contacts with the specified value (either name, phone or
    e-mail) in the currently running Skype application.
    """
    global skype_handle
    if not is_skype_running():
        launch_skype()
    if not skype_handle:
        skype_handle = Skype4Py.Skype()
        skype_handle.FriendlyName = conf.Title
        skype_handle.Attach() # Should open a confirmation dialog in Skype

    result = list(skype_handle.SearchForUsers(value))
    return result


def add_to_skype_contacts(users):
    """
    Adds the specified Skype4Py.User instances to Skype contacts in the
    currently Skype application.
    """
    global skype_handle
    if not is_skype_running():
        launch_skype()
    if not skype_handle:
        skype_handle = Skype4Py.Skype()
        skype_handle.FriendlyName = conf.Title
        skype_handle.Attach() # Should open a confirmation dialog in Skype
    for user in users:
        user.BuddyStatus = Skype4Py.enums.budPendingAuthorization
    skype_handle.Client.Focus()
